@@ -86,7 +86,7 @@
 #define KITEMMODELS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KITEMMODELS_NO_DEPRECATED
-#  define KITEMMODELS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54c00
+#  define KITEMMODELS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55100
 #endif
 #ifdef KITEMMODELS_NO_DEPRECATED_WARNINGS
 #  define KITEMMODELS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KITEMMODELS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KITEMMODELS_DEPRECATED_WARNINGS_SINCE KITEMMODELS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KITEMMODELS_DEPRECATED_WARNINGS_SINCE 0x54c00
+#    define KITEMMODELS_DEPRECATED_WARNINGS_SINCE 0x55100
 #  endif
 #endif
 
@@ -121,6 +121,12 @@
 #else
 #  define KITEMMODELS_DEPRECATED_VERSION_5_65(text)
 #endif
+
+#if KITEMMODELS_DEPRECATED_WARNINGS_SINCE >= 0x55000
+#  define KITEMMODELS_DEPRECATED_VERSION_5_80(text) KITEMMODELS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KITEMMODELS_DEPRECATED_VERSION_5_80(text)
+#endif
 #define KITEMMODELS_DEPRECATED_VERSION_4(minor, text)      KITEMMODELS_DEPRECATED_VERSION_4_##minor(text)
 #define KITEMMODELS_DEPRECATED_VERSION_5(minor, text)      KITEMMODELS_DEPRECATED_VERSION_5_##minor(text)
 #define KITEMMODELS_DEPRECATED_VERSION(major, minor, text) KITEMMODELS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
